@@ -23,6 +23,11 @@ import "codemirror/mode/clike/clike.js";
 import "codemirror/mode/octave/octave.js";
 import "./../css/activecode.css";
 import "codemirror/lib/codemirror.css";
+import "codemirror/addon/hint/show-hint.js";
+import "codemirror/addon/hint/show-hint.css";
+import "codemirror/addon/hint/sql-hint.js";
+import "codemirror/addon/hint/anyword-hint.js";
+import "codemirror/addon/edit/matchbrackets.js";
 import "./skulpt.min.js";
 import "./skulpt-stdlib.js";
 // Used by Skulpt.
@@ -43,6 +48,10 @@ window.edList = {};
 var socket, connection, doc;
 var chatcodesServer = "chat.codes";
 
+CodeMirror.commands.autocomplete = function (cm) {
+    cm.showHint({ hint: CodeMirror.hint.anyword });
+};
+
 // separate into constructor and init
 export class ActiveCode extends RunestoneBase {
     constructor(opts) {
@@ -73,6 +82,7 @@ export class ActiveCode extends RunestoneBase {
         this.loadButton = null;
         this.outerDiv = null;
         this.partner = "";
+        this.runCount = 0;
         this.logResults = true;
         if (!eBookConfig.allow_pairs || $(orig).data("nopair")) {
             this.enablePartner = false;
@@ -176,6 +186,7 @@ export class ActiveCode extends RunestoneBase {
             extraKeys: {
                 Tab: "indentMore",
                 "Shift-Tab": "indentLess",
+                "Ctrl-Space": "autocomplete",
             },
         });
         // Make the editor resizable
@@ -254,6 +265,10 @@ export class ActiveCode extends RunestoneBase {
         this.renderFeedback();
         // The run is finished; re-enable the button.
         this.runButton.disabled = false;
+        this.runCount += 1;
+        if (this.is_toggle && this.runCount == 3) {
+            alert("Help is Available Using the Toggle Question Selector");
+        }
     }
 
     createControls() {
@@ -476,8 +491,8 @@ export class ActiveCode extends RunestoneBase {
                     if (!didAgree) {
                         didAgree = confirm(
                             "Pair Programming should only be used with the consent of your instructor." +
-                            "Your partner must be a registered member of the class and have agreed to pair with you." +
-                            "By clicking OK you certify that both of these conditions have been met."
+                                "Your partner must be a registered member of the class and have agreed to pair with you." +
+                                "By clicking OK you certify that both of these conditions have been met."
                         );
                         if (didAgree) {
                             localStorage.setItem("partnerAgree", "true");
@@ -520,13 +535,13 @@ export class ActiveCode extends RunestoneBase {
         $(butt).attr(
             "href",
             "http://" +
-            chatcodesServer +
-            "/new?" +
-            $.param({
-                topic: window.location.host + "-" + this.divid,
-                code: this.editor.getValue(),
-                lang: "Python",
-            })
+                chatcodesServer +
+                "/new?" +
+                $.param({
+                    topic: window.location.host + "-" + this.divid,
+                    code: this.editor.getValue(),
+                    lang: "Python",
+                })
         );
         this.chatButton = butt;
         chatBar.appendChild(butt);
@@ -560,6 +575,8 @@ export class ActiveCode extends RunestoneBase {
         $(this.runButton).text($.i18n("msg_activecode_save_run"));
     }
 
+    // _`addHistoryScrubber`
+    // ---------------------
     // Activecode -- If the code has not changed wrt the scrubber position value then don't save the code or reposition the scrubber
     //  -- still call runlog, but add a parameter to not save the code
     // add an initial load history button
@@ -580,14 +597,23 @@ export class ActiveCode extends RunestoneBase {
             // If this is timed and already taken we should restore history info
             this.renderScrubber();
         } else {
-            let request = new Request(eBookConfig.ajaxURL + "gethist.json", {
-                method: "POST",
-                headers: this.jsonHeaders,
-                body: JSON.stringify(reqData),
-            });
+            let request = new Request(
+                `${eBookConfig.new_server_prefix}/assessment/gethist`,
+                {
+                    method: "POST",
+                    headers: this.jsonHeaders,
+                    body: JSON.stringify(reqData),
+                }
+            );
             try {
                 response = await fetch(request);
                 let data = await response.json();
+                if (!response.ok) {
+                    throw new Error(
+                        `Failed to get the history data: ${data.detail}`
+                    );
+                }
+                data = data.detail;
                 if (data.history !== undefined) {
                     this.history = this.history.concat(data.history);
                     for (let t in data.timestamps) {
@@ -597,7 +623,7 @@ export class ActiveCode extends RunestoneBase {
                     }
                 }
             } catch (e) {
-                console.log("unable to fetch history");
+                console.log(`unable to fetch history: ${e}`);
             }
             this.renderScrubber(pos_last);
         }
@@ -913,7 +939,7 @@ export class ActiveCode extends RunestoneBase {
         });
     }
 
-    toggleEditorVisibility() { }
+    toggleEditorVisibility() {}
 
     addErrorMessage(err) {
         // Add the error message
@@ -1051,7 +1077,7 @@ Yet another is that there is an internal error.  The internal error message is:
                     var xl = eval(x);
                     xl = xl.map(pyStr);
                     x = xl.join(" ");
-                } catch (err) { }
+                } catch (err) {}
             }
         }
         $(this.output).css("visibility", "visible");
@@ -1155,7 +1181,7 @@ Yet another is that there is an internal error.  The internal error message is:
         if (
             this.historyScrubber &&
             this.history[$(this.historyScrubber).slider("value")] !=
-            this.editor.getValue()
+                this.editor.getValue()
         ) {
             saveCode = "True";
             this.history.push(this.editor.getValue());
@@ -1193,9 +1219,9 @@ Yet another is that there is an internal error.  The internal error message is:
         let data = {
             div_id: this.divid,
             code: this.editor.getValue(),
-            lang: this.language,
-            errinfo: this.errinfo,
-            to_save: this.saveCode,
+            language: this.language,
+            errinfo: this.errinfo || "",
+            to_save: this.saveCode || "F",
             prefix: this.pretext,
             suffix: this.suffix,
             partner: this.partner,
@@ -1214,7 +1240,7 @@ Yet another is that there is an internal error.  The internal error message is:
             if (typeof sid !== "undefined") {
                 unitData.sid = sid;
             }
-            await this.logBookEvent(unitData)
+            await this.logBookEvent(unitData);
         }
     }
 
