@@ -173,6 +173,7 @@ export default class ClickableArea extends RunestoneBase {
                     this.logBookEvent({
                         event: "clickableArea",
                         act: this.clickedIndexArray.join(";"),
+                        answer: this.clickedIndexArray.join(";"),
                         div_id: this.divid,
                         correct: storageObj.correct,
                     });
@@ -276,7 +277,7 @@ export default class ClickableArea extends RunestoneBase {
                 if (
                     this.ccIndex < this.ccArray.length &&
                     this.ccCounter ===
-                    Math.floor(this.ccArray[this.ccIndex].split(",")[0]) &&
+                        Math.floor(this.ccArray[this.ccIndex].split(",")[0]) &&
                     Math.floor(this.ccArray[this.ccIndex].split(",")[1]) === 0
                 ) {
                     this.manageNewClickable(tComponentArr[t].children[i]);
@@ -285,7 +286,7 @@ export default class ClickableArea extends RunestoneBase {
                 } else if (
                     this.ciIndex < this.ciArray.length &&
                     this.ccCounter ===
-                    Math.floor(this.ciArray[this.ciIndex].split(",")[0]) &&
+                        Math.floor(this.ciArray[this.ciIndex].split(",")[0]) &&
                     Math.floor(this.ciArray[this.ciIndex].split(",")[1]) === 0
                 ) {
                     this.manageNewClickable(tComponentArr[t].children[i]);
@@ -302,13 +303,13 @@ export default class ClickableArea extends RunestoneBase {
                         if (
                             this.ccIndex < this.ccArray.length &&
                             tmp ===
-                            Math.floor(
-                                this.ccArray[this.ccIndex].split(",")[1]
-                            ) &&
+                                Math.floor(
+                                    this.ccArray[this.ccIndex].split(",")[1]
+                                ) &&
                             this.ccCounter ===
-                            Math.floor(
-                                this.ccArray[this.ccIndex].split(",")[0]
-                            )
+                                Math.floor(
+                                    this.ccArray[this.ccIndex].split(",")[0]
+                                )
                         ) {
                             this.manageNewClickable(
                                 tComponentArr[t].children[i].children[j]
@@ -320,13 +321,13 @@ export default class ClickableArea extends RunestoneBase {
                         } else if (
                             this.ciIndex < this.ciArray.length &&
                             tmp ===
-                            Math.floor(
-                                this.ciArray[this.ciIndex].split(",")[1]
-                            ) &&
+                                Math.floor(
+                                    this.ciArray[this.ciIndex].split(",")[1]
+                                ) &&
                             this.ccCounter ===
-                            Math.floor(
-                                this.ciArray[this.ciIndex].split(",")[0]
-                            )
+                                Math.floor(
+                                    this.ciArray[this.ciIndex].split(",")[0]
+                                )
                         ) {
                             this.manageNewClickable(
                                 tComponentArr[t].children[i].children[j]
@@ -400,9 +401,11 @@ export default class ClickableArea extends RunestoneBase {
     }
 
     async logCurrentAnswer(sid) {
+        const answer = this.givenIndexArray.join(";");
         let data = {
             event: "clickableArea",
-            act: this.givenIndexArray.join(";"),
+            answer: answer,
+            act: answer,
             div_id: this.divid,
             correct: this.correct ? "T" : "F",
         };
@@ -428,15 +431,15 @@ export default class ClickableArea extends RunestoneBase {
             }
             $(this.feedBackDiv).html(
                 "Incorrect. You clicked on " +
-                this.correctNum +
-                " of the " +
-                this.correctArray.length.toString() +
-                " correct elements and " +
-                this.incorrectNum +
-                " of the " +
-                this.incorrectArray.length.toString() +
-                " incorrect elements. " +
-                this.feedback
+                    this.correctNum +
+                    " of the " +
+                    this.correctArray.length.toString() +
+                    " correct elements and " +
+                    this.incorrectNum +
+                    " of the " +
+                    this.incorrectArray.length.toString() +
+                    " incorrect elements. " +
+                    this.feedback
             );
             $(this.feedBackDiv).attr("class", "alert alert-danger");
         }
