@@ -41,6 +41,7 @@ export default class SelectOne extends RunestoneBase {
         this.ABExperiment = $(opts.orig).data("ab");
         this.toggleOptions = $(opts.orig).data("toggleoptions");
         this.toggleLabels = $(opts.orig).data("togglelabels");
+        this.limitBaseCourse = $(opts.orig).data("limit-basecourse");
         opts.orig.id = this.selector_id;
     }
     /**
@@ -88,16 +89,23 @@ export default class SelectOne extends RunestoneBase {
         if (this.toggleLabels) {
             data.toggleLabels = this.toggleLabels;
         }
+        if (this.limitBaseCourse) {
+            data.limitBaseCourse = eBookConfig.basecourse;
+        }
         let opts = this.origOpts;
         let selectorId = this.selector_id;
         console.log("getting question source");
-        let request = new Request("/runestone/ajax/get_question_source", {
-            method: "POST",
-            headers: this.jsonHeaders,
-            body: JSON.stringify(data),
-        });
+        let request = new Request(
+            `${eBookConfig.new_server_prefix}/assessment/get_question_source`,
+            {
+                method: "POST",
+                headers: this.jsonHeaders,
+                body: JSON.stringify(data),
+            }
+        );
         let response = await fetch(request);
         let htmlsrc = await response.json();
+        htmlsrc = htmlsrc.detail;
         if (htmlsrc.indexOf("No preview") >= 0) {
             alert(
                 `Error: Not able to find a question for ${selectorId} based on the criteria`
@@ -126,7 +134,9 @@ export default class SelectOne extends RunestoneBase {
             self.realComponent.selectorId = selectorId;
         } else {
             if (data.toggleOptions) {
-                var toggleLabels = data.toggleLabels.replace("togglelabels:", "").trim();
+                var toggleLabels = data.toggleLabels
+                    .replace("togglelabels:", "")
+                    .trim();
                 if (toggleLabels) {
                     toggleLabels = toggleLabels.split(",");
                     for (var t = 0; t < toggleLabels.length; t++) {
@@ -139,9 +149,9 @@ export default class SelectOne extends RunestoneBase {
                 if (!document.getElementById("component-preview")) {
                     toggleUI +=
                         '<div id="component-preview" class="col-md-6 toggle-preview" style="z-index: 999;">' +
-                            '<div id="toggle-buttons"></div>' +
-                            '<div id="toggle-preview"></div>' +
-                        '</div>';
+                        '<div id="toggle-buttons"></div>' +
+                        '<div id="toggle-preview"></div>' +
+                        "</div>";
                 }
                 // dropdown menu containing the question options
                 toggleUI +=
@@ -159,9 +169,8 @@ export default class SelectOne extends RunestoneBase {
                     toggleQuestionHTMLSrc = await this.getToggleSrc(
                         toggleQuestions[i]
                     );
-                    toggleQuestionSubstring = toggleQuestionHTMLSrc.split(
-                        'data-component="'
-                    )[1];
+                    toggleQuestionSubstring =
+                        toggleQuestionHTMLSrc.split('data-component="')[1];
                     switch (
                         toggleQuestionSubstring.slice(
                             0,
@@ -191,26 +200,19 @@ export default class SelectOne extends RunestoneBase {
                             break;
                     }
                     toggleQuestionTypes[i] = toggleQuestionType;
-                    toggleUI +=
-                        '<option value="' +
-                        toggleQuestions[i] +
-                        '">';
+                    toggleUI += '<option value="' + toggleQuestions[i] + '">';
                     if (toggleLabels) {
                         if (toggleLabels[i]) {
                             toggleUI += toggleLabels[i];
+                        } else {
+                            toggleUI +=
+                                toggleQuestionType + " - " + toggleQuestions[i];
                         }
-                        else {
-                            toggleUI += toggleQuestionType +
-                            " - " +
-                            toggleQuestions[i];
-                        }
+                    } else {
+                        toggleUI +=
+                            toggleQuestionType + " - " + toggleQuestions[i];
                     }
-                    else {
-                        toggleUI += toggleQuestionType +
-                        " - " +
-                        toggleQuestions[i];
-                    }
-                    if ((i == 0) && (data.toggleOptions.includes("lock"))) {
+                    if (i == 0 && data.toggleOptions.includes("lock")) {
                         toggleUI += " (only this question will be graded)";
                     }
                     toggleUI += "</option>";
@@ -226,6 +228,8 @@ export default class SelectOne extends RunestoneBase {
             // just render this component on the page in its usual place
             await renderRunestoneComponent(htmlsrc, selectorId, {
                 selector_id: selectorId,
+                is_toggle: this.toggleOptions,
+                is_select: true,
                 useRunestoneServices: true,
             });
             if (data.toggleOptions) {
@@ -257,6 +261,11 @@ export default class SelectOne extends RunestoneBase {
                             data.toggleOptions,
                             toggleQuestionTypes
                         );
+                        this.logBookEvent({
+                            event: "view_toggle",
+                            act: toggleQuestionSelect.value,
+                            div_id: toggleQuestionSelect.parentElement.id,
+                        });
                     }.bind(this)
                 );
             }
@@ -267,13 +276,14 @@ export default class SelectOne extends RunestoneBase {
     // retrieve html source of a question, for use in various toggle functionalities
     async getToggleSrc(toggleQuestionID) {
         let request = new Request(
-            "/runestone/admin/htmlsrc?acid=" + toggleQuestionID,
+            `${eBookConfig.new_server_prefix}/assessment/htmlsrc?acid=${toggleQuestionID}`,
             {
                 method: "GET",
             }
         );
         let response = await fetch(request);
-        let htmlsrc = await response.json();
+        let data = await response.json();
+        let htmlsrc = data.detail;
         return htmlsrc;
     }
 
@@ -288,6 +298,8 @@ export default class SelectOne extends RunestoneBase {
         var htmlsrc = await this.getToggleSrc(selectedQuestion);
         renderRunestoneComponent(htmlsrc, "toggle-preview", {
             selector_id: "toggle-preview",
+            is_toggle: this.toggleOptions,
+            is_select: true,
             useRunestoneServices: true,
         });
 
@@ -304,15 +316,25 @@ export default class SelectOne extends RunestoneBase {
         });
         $("#toggle-buttons").append(closeButton);
 
-        // if "lock" is not in toggle options, then allow adding more buttons to the preview panel 
-        if (!(toggleOptions.includes("lock"))) {
+        // if "lock" is not in toggle options, then allow adding more buttons to the preview panel
+        if (!toggleOptions.includes("lock")) {
             let setButton = document.createElement("button");
             $(setButton).text("Select this Problem");
             $(setButton).addClass("btn btn-primary");
             $(setButton).click(
                 async function () {
-                    await this.toggleSet(parentID, selectedQuestion, htmlsrc, toggleQuestionTypes);
+                    await this.toggleSet(
+                        parentID,
+                        selectedQuestion,
+                        htmlsrc,
+                        toggleQuestionTypes
+                    );
                     $("#component-preview").hide();
+                    this.logBookEvent({
+                        event: "select_toggle",
+                        act: selectedQuestion,
+                        div_id: parentID,
+                    });
                 }.bind(this)
             );
             $("#toggle-buttons").append(setButton);
@@ -320,14 +342,23 @@ export default class SelectOne extends RunestoneBase {
             // if "transfer" in toggle options, and if current question type is Parsons and selected question type is active code, then add "Transfer" button to preview panel
             if (toggleOptions.includes("transfer")) {
                 var currentType = $("#" + parentID).data("toggle_current_type");
-                var selectedType = toggleQuestionTypes[toggleQuestionSelect.selectedIndex];
-                if ((currentType == "Parsons Mixed-Up Code") && (selectedType == "Active Write Code")) {
+                var selectedType =
+                    toggleQuestionTypes[toggleQuestionSelect.selectedIndex];
+                if (
+                    currentType == "Parsons Mixed-Up Code" &&
+                    selectedType == "Active Write Code"
+                ) {
                     let transferButton = document.createElement("button");
                     $(transferButton).text("Transfer Response");
                     $(transferButton).addClass("btn btn-primary");
                     $(transferButton).click(
                         async function () {
-                            await this.toggleTransfer(parentID, selectedQuestion, htmlsrc, toggleQuestionTypes);
+                            await this.toggleTransfer(
+                                parentID,
+                                selectedQuestion,
+                                htmlsrc,
+                                toggleQuestionTypes
+                            );
                         }.bind(this)
                     );
                     $("#toggle-buttons").append(transferButton);
@@ -339,34 +370,47 @@ export default class SelectOne extends RunestoneBase {
     }
 
     // on clicking "Select this Problem" button, close preview panel, replace current question in assignments page with selected question, and send request to update grading database
+    // _ `toggleSet`
     async toggleSet(parentID, selectedQuestion, htmlsrc, toggleQuestionTypes) {
         var selectorId = parentID + "-toggleSelectedQuestion";
-        var toggleQuestionSelect = document.getElementById(parentID).getElementsByTagName("select")[0];
+        var toggleQuestionSelect = document
+            .getElementById(parentID)
+            .getElementsByTagName("select")[0];
         document.getElementById(selectorId).innerHTML = ""; // need to check whether this is even necessary
         await renderRunestoneComponent(htmlsrc, selectorId, {
             selector_id: selectorId,
+            is_toggle: this.toggleOptions,
+            is_select: true,
             useRunestoneServices: true,
         });
         let request = new Request(
-            "/runestone/ajax/update_selected_question?metaid=" +
-                parentID +
-                "&selected=" +
-                selectedQuestion,
+            `${eBookConfig.new_server_prefix}/assessment/set_selected_question?metaid=${parentID}&selected=${selectedQuestion}`,
             {}
         );
         await fetch(request);
         $("#toggle-preview").html("");
         $("#" + parentID).data("toggle_current", selectedQuestion);
-        $("#" + parentID).data("toggle_current_type", toggleQuestionTypes[toggleQuestionSelect.selectedIndex]);
+        $("#" + parentID).data(
+            "toggle_current_type",
+            toggleQuestionTypes[toggleQuestionSelect.selectedIndex]
+        );
     }
 
     // on clicking "Transfer" button, extract the current text and indentation of the Parsons blocks in the answer space, then paste that into the selected active code question
-    async toggleTransfer(parentID, selectedQuestion, htmlsrc, toggleQuestionTypes) {
+    async toggleTransfer(
+        parentID,
+        selectedQuestion,
+        htmlsrc,
+        toggleQuestionTypes
+    ) {
         // retrieve all Parsons lines within the answer space and loop through this list
-        var currentParsons = document.getElementById(parentID + "-toggleSelectedQuestion").querySelectorAll("div[class^='answer']")[0].getElementsByClassName("prettyprint lang-py");
+        var currentParsons = document
+            .getElementById(parentID + "-toggleSelectedQuestion")
+            .querySelectorAll("div[class^='answer']")[0]
+            .getElementsByClassName("prettyprint lang-py");
         var currentParsonsClass;
         var currentBlockIndent;
-        var indentCount
+        var indentCount;
         var indent;
         var parsonsLine;
         var parsonsLines = ``;
@@ -378,13 +422,28 @@ export default class SelectOne extends RunestoneBase {
             currentParsonsClass = currentParsons[p].classList[2];
             if (currentParsonsClass) {
                 if (currentParsonsClass.includes("indent")) {
-                    indentCount = parseInt(indentCount) + parseInt(currentParsonsClass.slice(6,currentParsonsClass.length));
+                    indentCount =
+                        parseInt(indentCount) +
+                        parseInt(
+                            currentParsonsClass.slice(
+                                6,
+                                currentParsonsClass.length
+                            )
+                        );
                 }
             }
             // for Parsons answer spaces with vertical lines that allow student to define their own line indentation
-            currentBlockIndent = currentParsons[p].parentElement.parentElement.style.left;
+            currentBlockIndent =
+                currentParsons[p].parentElement.parentElement.style.left;
             if (currentBlockIndent) {
-                indentCount = parseInt(indentCount) + parseInt(currentBlockIndent.slice(0,currentBlockIndent.indexOf("px")) / 30);
+                indentCount =
+                    parseInt(indentCount) +
+                    parseInt(
+                        currentBlockIndent.slice(
+                            0,
+                            currentBlockIndent.indexOf("px")
+                        ) / 30
+                    );
             }
             for (var d = 0; d < indentCount; d++) {
                 indent += "    ";
@@ -393,41 +452,60 @@ export default class SelectOne extends RunestoneBase {
             parsonsLine = currentParsons[p].getElementsByTagName("span");
             count = 0;
             for (var l = 0; l < parsonsLine.length; l++) {
-                if (parsonsLine[l].childNodes[0].nodeName == "#text") { // Parsons blocks have differing amounts of hierarchy levels (spans within spans)
-                    if ((p == 0) && (count == 0)) { // need different check than l == 0 because the l numbering doesn't align with location within line due to inconsistent span heirarchy
+                if (parsonsLine[l].childNodes[0].nodeName == "#text") {
+                    // Parsons blocks have differing amounts of hierarchy levels (spans within spans)
+                    if (p == 0 && count == 0) {
+                        // need different check than l == 0 because the l numbering doesn't align with location within line due to inconsistent span heirarchy
                         parsonsLines += indent + parsonsLine[l].innerHTML;
                         count++;
-                    }
-                    else if (count != 0) {
+                    } else if (count != 0) {
                         parsonsLines += parsonsLine[l].innerHTML;
                         count++;
-                    }
-                    else {
-                        parsonsLines = parsonsLines + `
-                            ` + indent + parsonsLine[l].innerHTML;
-                        parsonsLines = parsonsLines.replace("                            ", "");
+                    } else {
+                        parsonsLines =
+                            parsonsLines +
+                            `
+                            ` +
+                            indent +
+                            parsonsLine[l].innerHTML;
+                        parsonsLines = parsonsLines.replace(
+                            "                            ",
+                            ""
+                        );
                         count++;
                     }
                 }
             }
         }
         // replace all existing code within selected active code question with extracted Parsons text
-        var htmlsrcFormer = htmlsrc.slice(0, htmlsrc.indexOf("<textarea") + htmlsrc.split("<textarea")[1].indexOf(">") + 10);
-        var htmlsrcLatter = htmlsrc.slice(htmlsrc.indexOf("</textarea>"), htmlsrc.length);
+        var htmlsrcFormer = htmlsrc.slice(
+            0,
+            htmlsrc.indexOf("<textarea") +
+                htmlsrc.split("<textarea")[1].indexOf(">") +
+                10
+        );
+        var htmlsrcLatter = htmlsrc.slice(
+            htmlsrc.indexOf("</textarea>"),
+            htmlsrc.length
+        );
         htmlsrc = htmlsrcFormer + parsonsLines + htmlsrcLatter;
 
-        await this.toggleSet(parentID, selectedQuestion, htmlsrc, toggleQuestionTypes);
+        await this.toggleSet(
+            parentID,
+            selectedQuestion,
+            htmlsrc,
+            toggleQuestionTypes
+        );
         $("#component-preview").hide();
     }
 }
 
-
 if (typeof window.component_factory === "undefined") {
     window.component_factory = {};
 }
 
 window.component_factory.selectquestion = function (opts) {
-        return new SelectOne(opts);
+    return new SelectOne(opts);
 };
 
 /*
