@@ -84,7 +84,7 @@ def get_dburl(outer={}):
         # DAL uses "postgres:", while SQLAlchemy (and the PostgreSQL spec) uses "postgresql:". Fix.
         remove_prefix = "postgres://"
         if dburl.startswith(remove_prefix):
-            dburl = "postgresql://" + dburl[len(remove_prefix):]
+            dburl = "postgresql://" + dburl[len(remove_prefix) :]
         return dburl
 
     raise RuntimeError("Cannot configure a Database URL!")
@@ -128,7 +128,11 @@ def setup(app):
     logger.info("Connecting to DB")
     try:
         dburl = get_dburl()
-        engine = create_engine(dburl, client_encoding="utf8", convert_unicode=True)
+        # SQLite doesn't support ``client_encoding``, while PostgreSQL does.
+        encoding = (
+            dict(client_encoding="utf8") if dburl.startswith("postgresql") else {}
+        )
+        engine = create_engine(dburl, convert_unicode=True, **encoding)
         Session = sessionmaker()
         engine.connect()
         Session.configure(bind=engine)
@@ -268,7 +272,13 @@ def addQuestionToDB(self):
             author = os.environ.get("USER", "Brad Miller")
 
         autograde = self.options.get("autograde", None)
-        practice = self.options.get("practice", None)
+        if "practice" in self.options:
+            value = self.options["practice"].upper()
+            assert value == "T" or value == "F", f":practice: must be T or F not '{value}'"
+            practice = value
+        else:
+            practice = None
+
         if ("topics" in self.options) and (self.options["topics"] != ""):
             topics = self.options["topics"]
         else:
@@ -339,6 +349,7 @@ def addQuestionToDB(self):
                     practice=practice,
                     topic=topics,
                     from_source=from_source,
+                    review_flag="F",
                     optional=optional,
                     description=et,
                     **meta_opts,
@@ -388,6 +399,7 @@ def addQuestionToDB(self):
                     question_name=id_,
                 )
                 sess.execute(ins)
+            sess.commit()
 
 
 def addQNumberToDB(app, node, qnumber):
@@ -412,7 +424,9 @@ def addQNumberToDB(app, node, qnumber):
                 questions.c.base_course == basecourse,
             )
         )
-        .values(qnumber=qnumber,)
+        .values(
+            qnumber=qnumber,
+        )
     )
     sess.execute(stmt)
 
@@ -585,7 +599,6 @@ def addAssignmentToDB(
         return
 
     course_id = getCourseID(course_name)
-    last_changed = datetime.now()
     sel = select([assignments]).where(
         and_(assignments.c.name == name, assignments.c.course == course_id)
     )
@@ -624,6 +637,7 @@ def addAssignmentToDB(
             visible=visible,
             time_limit=time_limit,
             from_source="T",
+            released="F",
         )
         res = sess.execute(ins)
         a_id = res.inserted_primary_key[0]
